@@ -22,13 +22,17 @@ public class GridHeaderColumnMenu {
 	public GridHeaderColumnMenu() {
 		menuItems = new ArrayList<MenuItem>();
 		
+		MenuItem changePositionItem = new MenuItem("Position Column");
+		changePositionItem.setId(GridHeaderOperationId.COLUMNPOSITION
+				.toString());
+		changePositionItem.setIcon(MainboxResources.INSTANCE.columnReorder());
+		menuItems.add(changePositionItem);
 		
 		MenuItem changeLabelItem = new MenuItem("Labels");
 		changeLabelItem.setId(GridHeaderOperationId.COLUMNLABEL
 				.toString());
 		changeLabelItem.setIcon(MainboxResources.INSTANCE.columnLabel());
 		menuItems.add(changeLabelItem);
-		
 	
 		MenuItem addColumnItem = new MenuItem("Add Column");
 		addColumnItem.setId(GridHeaderOperationId.COLUMNADD.toString());
@@ -54,7 +58,7 @@ public class GridHeaderColumnMenu {
 		
 		
 		
-		MenuItem changeToTypeItem = new MenuItem("Change Type");
+		MenuItem changeToTypeItem = new MenuItem("Column Type");
 		changeToTypeItem.setId(GridHeaderOperationId.COLUMNTYPE.toString());
 		changeToTypeItem.setIcon(MainboxResources.INSTANCE.columnType());	
 		menuItems.add(changeToTypeItem);
@@ -70,7 +74,6 @@ public class GridHeaderColumnMenu {
 		replaceValueBatchItem.setIcon(MainboxResources.INSTANCE.columnReplaceBatch());	
 		menuItems.add(replaceValueBatchItem);
 		
-
 		MenuItem replaceValueOnConditionItem = new MenuItem("Replace By Expression");
 		replaceValueOnConditionItem.setId(GridHeaderOperationId.COLUMNREPLACEBYEXPRESSION.toString());
 		replaceValueOnConditionItem.setIcon(MainboxResources.INSTANCE.columnReplaceByExpression());	
@@ -81,6 +84,12 @@ public class GridHeaderColumnMenu {
 		replaceValueByExternalItem.setIcon(MainboxResources.INSTANCE.columnReplaceByExternal());	
 		menuItems.add(replaceValueByExternalItem);
 		
+		/*MenuItem downscaleCSquareItem = new MenuItem("Downscale C-Square");
+		downscaleCSquareItem.setId(GridHeaderOperationId.DOWNSCALECSQUARE.toString());
+		downscaleCSquareItem.setIcon(MainboxResources.INSTANCE.downscaleCSquare());	
+		menuItems.add(downscaleCSquareItem);*/
+		
+		
 		
 		/*MenuItem newAnnotationColumnItem = new MenuItem("Annotation");
 		newAnnotationColumnItem.setId(GridHeaderOperationId.ANNOTATIONADD.toString());
